==> haskell-wai-cors-0.2.7-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-cors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-cors
version:              0.2.7
visibility:           public
id:                   wai-cors-0.2.7-jyiqfNj1Ej4itRAqv69ss
key:                  wai-cors-0.2.7-jyiqfNj1Ej4itRAqv69ss
license:              MIT
copyright:
    (c) 2015-2019 Lars Kuhtz <lakuhtz@gmail.com>,
    (c) 2014 AlephCloud Systems, Inc.

maintainer:           Lars Kuhtz <lakuhtz@gmail.com>
author:               Lars Kuhtz <lakuhtz@gmail.com>
homepage:             https://github.com/larskuhtz/wai-cors
synopsis:             CORS for WAI
description:
    This package provides an implemenation of
    Cross-Origin resource sharing (CORS) for
    <http://hackage.haskell.org/package/wai Wai>
    that aims to be compliant with <http://www.w3.org/TR/cors>.

category:             HTTP, Network, Web, Wai
abi:                  817f53a6d538d0d8ad13abb2b29abb39
exposed:              True
exposed-modules:      Network.Wai.Middleware.Cors
import-dirs:          /usr/lib/ghc-8.10.1/site-local/wai-cors-0.2.7
library-dirs:         /usr/lib/ghc-8.10.1/site-local/wai-cors-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/wai-cors-0.2.7
hs-libraries:         HSwai-cors-0.2.7-jyiqfNj1Ej4itRAqv69ss
depends:
    attoparsec-0.13.2.4-GOTdzZbG0wqBeikq1tq7Wl base-4.14.0.0
    base-unicode-symbols-0.2.4.2-vnVOBvjTNUBN7IzyjwGBX
    bytestring-0.10.10.0
    case-insensitive-1.2.1.0-8AZUbBQpbxTCPQBw8ziEWX
    http-types-0.12.3-1k0WB5pPAzWD05tRRqh9hH mtl-2.2.2
    transformers-0.5.6.2 wai-3.2.2.1-53P08uWRvZaJG0EMtvDpNi

haddock-interfaces:   /usr/share/doc/haskell-wai-cors/html/wai-cors.haddock
haddock-html:         /usr/share/doc/haskell-wai-cors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-cors-0.2.7-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-cors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-cors
version:              0.2.7
visibility:           public
id:                   wai-cors-0.2.7-Dt9LesAvdggAPnKnUWdHxp
key:                  wai-cors-0.2.7-Dt9LesAvdggAPnKnUWdHxp
license:              MIT
copyright:
    (c) 2015-2019 Lars Kuhtz <lakuhtz@gmail.com>,
    (c) 2014 AlephCloud Systems, Inc.

maintainer:           Lars Kuhtz <lakuhtz@gmail.com>
author:               Lars Kuhtz <lakuhtz@gmail.com>
homepage:             https://github.com/larskuhtz/wai-cors
synopsis:             CORS for WAI
description:
    This package provides an implemenation of
    Cross-Origin resource sharing (CORS) for
    <http://hackage.haskell.org/package/wai Wai>
    that aims to be compliant with <http://www.w3.org/TR/cors>.

category:             HTTP, Network, Web, Wai
abi:                  402597fa58aea3537554b8fc27fc949e
exposed:              True
exposed-modules:      Network.Wai.Middleware.Cors
import-dirs:          /usr/lib/ghc-8.10.1/site-local/wai-cors-0.2.7
library-dirs:         /usr/lib/ghc-8.10.1/site-local/wai-cors-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/wai-cors-0.2.7
hs-libraries:         HSwai-cors-0.2.7-Dt9LesAvdggAPnKnUWdHxp
depends:
    attoparsec-0.13.2.4-GOTdzZbG0wqBeikq1tq7Wl base-4.14.0.0
    base-unicode-symbols-0.2.4.2-vnVOBvjTNUBN7IzyjwGBX
    bytestring-0.10.10.0
    case-insensitive-1.2.1.0-8AZUbBQpbxTCPQBw8ziEWX
    http-types-0.12.3-1kde9KJAuu38Zmp5WnQ1fU mtl-2.2.2
    transformers-0.5.6.2 wai-3.2.2.1-3MZN0hsjN1f5dgCtoZeKBL

haddock-interfaces:   /usr/share/doc/haskell-wai-cors/html/wai-cors.haddock
haddock-html:         /usr/share/doc/haskell-wai-cors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
